package com.persagy.transfer.cache;

import java.util.Map;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;

import com.persagy.transfer.constant.SwitchConstant;
import com.persagy.transfer.pojo.dto.WdclassRelPersagy;

import cn.hutool.core.collection.ConcurrentHashSet;

/**
 * 本地数据缓存
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021年9月16日 下午10:45:09
 */
public class LocalCache {

	/** 本地设备类编码缓存 */
	public static Set<String> BDTP_CLASS_CODE_BY_WD = new ConcurrentHashSet<String>(32);
	
	/**
	 * 本地设备类编码对象缓存
	 * 
	 * key: BDTP-classCode + WD_buildCode，_ 作为分隔符
	 * value: 设备类中间表对象
	 */
	public static Map<String, WdclassRelPersagy> CLASS_CODE_MAPPING_BY_WD = new ConcurrentHashMap<String, WdclassRelPersagy>(32);
	
	/**
	 * 本地项目映射缓存
	 * 
	 * key: BDTP-projectId
	 * value: WD-projectId
	 */
	public static Map<String, String> PROJECT_MAPPING_BY_WD = new ConcurrentHashMap<String, String>();

	/**
	 * CLASS_CODE_MAPPING_BY_WD 的缓存key生成
	 * 
	 * @company persagy 
	 * @author zhangqiankun
	 * @date 2021年9月16日 下午11:07:22
	 */
	public static String getWDCacheKey(String classCode, String wdBuildCode) {
		return classCode + SwitchConstant.UNDERLINE + wdBuildCode;
	}
	
}
