package com.persagy.transfer.handle;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.persagy.common.utils.StringUtil;
import com.persagy.transfer.cache.LocalCache;
import com.persagy.transfer.pojo.dto.WdclassRelPersagy;
import com.persagy.transfer.pojo.dto.WdprojRelPersagyproj;
import com.persagy.transfer.service.IWdclassRelPersagyService;
import com.persagy.transfer.service.IWdprojRelPersagyprojService;

import cn.hutool.core.collection.CollectionUtil;

/**
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021年9月17日 上午10:13:53
 */
@Component
public class CommonHandler {

    @Autowired
    private IWdclassRelPersagyService wdclassRelPersagyService;
    
    @Autowired
    private IWdprojRelPersagyprojService wdprojRelPersagyprojService;
    
	/**
	 * 创建万达的本地类型编码缓存
	 * 
	 * @company persagy 
	 * @author zhangqiankun
	 * @date 2021年9月16日 下午11:04:07
	 */
	public void createWDClassCache() {
		// 先清除缓存
		LocalCache.BDTP_CLASS_CODE_BY_WD.clear();
		LocalCache.CLASS_CODE_MAPPING_BY_WD.clear();
		
		// 缓存添加
		LambdaQueryWrapper<WdclassRelPersagy> queryWrapper = new WdclassRelPersagy.BuilderQueryWrapper().builder();
    	List<WdclassRelPersagy> list = this.wdclassRelPersagyService.list(queryWrapper);
    	if (CollectionUtil.isNotEmpty(list)) {
    		for (WdclassRelPersagy wdclassRelPersagy : list) {
    			LocalCache.BDTP_CLASS_CODE_BY_WD.add(wdclassRelPersagy.getClassCode());
    			LocalCache.CLASS_CODE_MAPPING_BY_WD.put(LocalCache.getWDCacheKey(wdclassRelPersagy.getClassCode(), wdclassRelPersagy.getWdBuildCode()), wdclassRelPersagy);
			}
		}
	}

	/**
	 * 创建万达的项目映射缓存
	 * 
	 * @company persagy 
	 * @author zhangqiankun
	 * @date 2021年9月16日 下午11:04:07
	 */
	public void createWDProjectCache() {
		// 先清除缓存
		LocalCache.PROJECT_MAPPING_BY_WD.clear();
		
		// 本地缓存添加
		LambdaQueryWrapper<WdprojRelPersagyproj> queryWrapper = new WdprojRelPersagyproj.BuilderQueryWrapper().builder();
    	List<WdprojRelPersagyproj> list = this.wdprojRelPersagyprojService.list(queryWrapper);
    	if (CollectionUtil.isNotEmpty(list)) {
    		for (WdprojRelPersagyproj wdprojRelPersagyproj : list) {
    			if (StringUtil.isAllNotBlank(wdprojRelPersagyproj.getPersagyProjectid(), wdprojRelPersagyproj.getWdProjectid())) {
    				LocalCache.PROJECT_MAPPING_BY_WD.put(wdprojRelPersagyproj.getPersagyProjectid(), wdprojRelPersagyproj.getWdProjectid());
    			}
			}
    	}
	}
	
}
