package com.persagy.transfer.pojo.dto;

import com.baomidou.mybatisplus.annotation.FieldStrategy;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import com.persagy.common.utils.StringUtil;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

import java.util.Date;

/**
 * 设备信息主表
 *
 * @author zhangqiankun
 * @version 1.0.0
 * @company persagy
 * @date 2021-09-16 10:45:41
 */
@Getter
@Setter
@ToString
@EqualsAndHashCode(callSuper = false)
@TableName("hydomc_asset")
public class HydomcAsset extends Model<HydomcAsset> {
    private static final long serialVersionUID = -6974983990373376067L;

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String sbybm;

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String siteid; // 项目唯一id，可采用租赁系统广场id，同步后不可更改

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String description; // 设备名称

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String wzqy; // 设备安装位置,详细设备安装位置，格式：楼体-楼层-区域

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String fwqy; // 设备服务区域

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String sbxh; // 设备型号

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String classstructureid; // 对接设备分类id，同步后不可更改

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String status; // 设备状态,运行中/报废,默认都为运行中

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String sbxhh; // 设备序号,同类设备的序号，即第几台设备：第几台电梯

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String cjsbxh; // 厂家设备序列号

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String manufacturer; // 生产商公司供方管理系统编码code

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String vendor; // 供应商公司供方管理系统编码code

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String fws; // 服务商公司供方管理系统编码code

    @TableField(updateStrategy = FieldStrategy.NOT_NULL)
    private Double purchaseprice; // 采购金额,填写人民币元

    @TableField(updateStrategy = FieldStrategy.NOT_NULL)
    private Double zjsynx; // 折旧/使用年限,按年填写 如3年半则填写 3.5

    @TableField(updateStrategy = FieldStrategy.NOT_NULL)
    private Date scrq; // 生产日期/出厂日期

    @TableField(updateStrategy = FieldStrategy.NOT_NULL)
    private Date cgrq; // 采购日期

    @TableField(updateStrategy = FieldStrategy.NOT_NULL)
    private Date azdate; // 安装日期

    @TableField(updateStrategy = FieldStrategy.NOT_NULL)
    private Date installdate; // 启用日期

    @TableField(updateStrategy = FieldStrategy.NOT_NULL)
    private Date zbksrq; // 质保开始日期

    @TableField(updateStrategy = FieldStrategy.NOT_NULL)
    private Date zbjsrq; // 质保结束日期

    @TableField(updateStrategy = FieldStrategy.NOT_NULL)
    private Integer zxzq; // 中修周期,单位为月

    @TableField(updateStrategy = FieldStrategy.NOT_NULL)
    private Integer dxzq; // 大修周期,单位为月

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String wylx; // 物业类型,自持/销售/合作方

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String sbglgs; // 设备管理归属,商管/百货/大歌星/超市/影院/大酒楼/其他

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String hysbbm; // 慧云设备编码

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String sfhysy; // 是否慧云使用,是/否,缺省为 是

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String sfzld; // 是否是主力店,缺省为 否

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String mark; // 备注

    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String datastatus; // 数据状态,update/delete 当数据状态为delete时，设备状态需改为报废

    @TableField(updateStrategy = FieldStrategy.NOT_NULL)
    private Date changedate; // 数据更新时间

    @TableField(updateStrategy = FieldStrategy.NOT_NULL)
    private String ctx; // 变更人员的万信账号


    public static Builder builder() {
        return new Builder();
    }

    public static class BuilderQueryWrapper {

        private LambdaQueryWrapper<HydomcAsset> queryWrapper = new LambdaQueryWrapper<>();

        public BuilderQueryWrapper siteidEq(String siteid) {
            if (StringUtil.isNotBlank(siteid)) {
                queryWrapper.eq(HydomcAsset::getSiteid, siteid);
            }
            return this;
        }

        public BuilderQueryWrapper sbybmEq(String sbybm) {
            if (StringUtil.isNotBlank(sbybm)) {
                queryWrapper.eq(HydomcAsset::getSbybm, sbybm);
            }
            return this;
        }

        public BuilderQueryWrapper descriptionEq(String description) {
            if (StringUtil.isNotBlank(description)) {
                queryWrapper.eq(HydomcAsset::getDescription, description);
            }
            return this;
        }

        public BuilderQueryWrapper wzqyEq(String wzqy) {
            if (StringUtil.isNotBlank(wzqy)) {
                queryWrapper.eq(HydomcAsset::getWzqy, wzqy);
            }
            return this;
        }

        public BuilderQueryWrapper fwqyEq(String fwqy) {
            if (StringUtil.isNotBlank(fwqy)) {
                queryWrapper.eq(HydomcAsset::getFwqy, fwqy);
            }
            return this;
        }

        public BuilderQueryWrapper sbxhEq(String sbxh) {
            if (StringUtil.isNotBlank(sbxh)) {
                queryWrapper.eq(HydomcAsset::getSbxh, sbxh);
            }
            return this;
        }

        public BuilderQueryWrapper classstructureidEq(String classstructureid) {
            if (StringUtil.isNotBlank(classstructureid)) {
                queryWrapper.eq(HydomcAsset::getClassstructureid, classstructureid);
            }
            return this;
        }

        public BuilderQueryWrapper statusEq(String status) {
            if (StringUtil.isNotBlank(status)) {
                queryWrapper.eq(HydomcAsset::getStatus, status);
            }
            return this;
        }

        public BuilderQueryWrapper sbxhhEq(String sbxhh) {
            if (StringUtil.isNotBlank(sbxhh)) {
                queryWrapper.eq(HydomcAsset::getSbxhh, sbxhh);
            }
            return this;
        }

        public BuilderQueryWrapper cjsbxhEq(String cjsbxh) {
            if (StringUtil.isNotBlank(cjsbxh)) {
                queryWrapper.eq(HydomcAsset::getCjsbxh, cjsbxh);
            }
            return this;
        }

        public BuilderQueryWrapper manufacturerEq(String manufacturer) {
            if (StringUtil.isNotBlank(manufacturer)) {
                queryWrapper.eq(HydomcAsset::getManufacturer, manufacturer);
            }
            return this;
        }

        public BuilderQueryWrapper vendorEq(String vendor) {
            if (StringUtil.isNotBlank(vendor)) {
                queryWrapper.eq(HydomcAsset::getVendor, vendor);
            }
            return this;
        }

        public BuilderQueryWrapper fwsEq(String fws) {
            if (StringUtil.isNotBlank(fws)) {
                queryWrapper.eq(HydomcAsset::getFws, fws);
            }
            return this;
        }

        public BuilderQueryWrapper purchasepriceEq(Double purchaseprice) {
            if (null != purchaseprice) {
                queryWrapper.eq(HydomcAsset::getPurchaseprice, purchaseprice);
            }
            return this;
        }

        public BuilderQueryWrapper zjsynxEq(Double zjsynx) {
            if (null != zjsynx) {
                queryWrapper.eq(HydomcAsset::getZjsynx, zjsynx);
            }
            return this;
        }

        public BuilderQueryWrapper scrqEq(Date scrq) {
            if (null != scrq) {
                queryWrapper.eq(HydomcAsset::getScrq, scrq);
            }
            return this;
        }

        public BuilderQueryWrapper cgrqEq(Date cgrq) {
            if (null != cgrq) {
                queryWrapper.eq(HydomcAsset::getCgrq, cgrq);
            }
            return this;
        }

        public BuilderQueryWrapper azdateEq(Date azdate) {
            if (null != azdate) {
                queryWrapper.eq(HydomcAsset::getAzdate, azdate);
            }
            return this;
        }

        public BuilderQueryWrapper installdateEq(Date installdate) {
            if (null != installdate) {
                queryWrapper.eq(HydomcAsset::getInstalldate, installdate);
            }
            return this;
        }

        public BuilderQueryWrapper zbksrqEq(Date zbksrq) {
            if (null != zbksrq) {
                queryWrapper.eq(HydomcAsset::getZbksrq, zbksrq);
            }
            return this;
        }

        public BuilderQueryWrapper zbjsrqEq(Date zbjsrq) {
            if (null != zbjsrq) {
                queryWrapper.eq(HydomcAsset::getZbjsrq, zbjsrq);
            }
            return this;
        }

        public BuilderQueryWrapper zxzqEq(Integer zxzq) {
            if (null != zxzq) {
                queryWrapper.eq(HydomcAsset::getZxzq, zxzq);
            }
            return this;
        }

        public BuilderQueryWrapper dxzqEq(Integer dxzq) {
            if (null != dxzq) {
                queryWrapper.eq(HydomcAsset::getDxzq, dxzq);
            }
            return this;
        }

        public BuilderQueryWrapper wylxEq(String wylx) {
            if (StringUtil.isNotBlank(wylx)) {
                queryWrapper.eq(HydomcAsset::getWylx, wylx);
            }
            return this;
        }

        public BuilderQueryWrapper sbglgsEq(String sbglgs) {
            if (StringUtil.isNotBlank(sbglgs)) {
                queryWrapper.eq(HydomcAsset::getSbglgs, sbglgs);
            }
            return this;
        }

        public BuilderQueryWrapper hysbbmEq(String hysbbm) {
            if (StringUtil.isNotBlank(hysbbm)) {
                queryWrapper.eq(HydomcAsset::getHysbbm, hysbbm);
            }
            return this;
        }

        public BuilderQueryWrapper sfhysyEq(String sfhysy) {
            if (StringUtil.isNotBlank(sfhysy)) {
                queryWrapper.eq(HydomcAsset::getSfhysy, sfhysy);
            }
            return this;
        }

        public BuilderQueryWrapper ctxEq(String ctx) {
            if (StringUtil.isNotBlank(ctx)) {
                queryWrapper.eq(HydomcAsset::getCtx, ctx);
            }
            return this;
        }

        public BuilderQueryWrapper sfzldEq(String sfzld) {
            if (StringUtil.isNotBlank(sfzld)) {
                queryWrapper.eq(HydomcAsset::getSfzld, sfzld);
            }
            return this;
        }

        public BuilderQueryWrapper markEq(String mark) {
            if (StringUtil.isNotBlank(mark)) {
                queryWrapper.eq(HydomcAsset::getMark, mark);
            }
            return this;
        }

        public BuilderQueryWrapper datastatusEq(String datastatus) {
            if (StringUtil.isNotBlank(datastatus)) {
                queryWrapper.eq(HydomcAsset::getDatastatus, datastatus);
            }
            return this;
        }

        public BuilderQueryWrapper changedateEq(Date changedate) {
            if (null != changedate) {
                queryWrapper.eq(HydomcAsset::getChangedate, changedate);
            }
            return this;
        }

        public LambdaQueryWrapper<HydomcAsset> builder() {
            return queryWrapper;
        }

    }

    public static class BuilderUpdateWrapper {

        private LambdaUpdateWrapper<HydomcAsset> updateWrapper = new LambdaUpdateWrapper<>();

        public BuilderUpdateWrapper siteidEq(String siteid) {
            if (StringUtil.isNotBlank(siteid)) {
                updateWrapper.eq(HydomcAsset::getSiteid, siteid);
            }
            return this;
        }

        public BuilderUpdateWrapper sbybmEq(String sbybm) {
            if (StringUtil.isNotBlank(sbybm)) {
                updateWrapper.eq(HydomcAsset::getSbybm, sbybm);
            }
            return this;
        }

        public BuilderUpdateWrapper descriptionEq(String description) {
            if (StringUtil.isNotBlank(description)) {
                updateWrapper.eq(HydomcAsset::getDescription, description);
            }
            return this;
        }

        public BuilderUpdateWrapper wzqyEq(String wzqy) {
            if (StringUtil.isNotBlank(wzqy)) {
                updateWrapper.eq(HydomcAsset::getWzqy, wzqy);
            }
            return this;
        }

        public BuilderUpdateWrapper fwqyEq(String fwqy) {
            if (StringUtil.isNotBlank(fwqy)) {
                updateWrapper.eq(HydomcAsset::getFwqy, fwqy);
            }
            return this;
        }

        public BuilderUpdateWrapper sbxhEq(String sbxh) {
            if (StringUtil.isNotBlank(sbxh)) {
                updateWrapper.eq(HydomcAsset::getSbxh, sbxh);
            }
            return this;
        }

        public BuilderUpdateWrapper classstructureidEq(String classstructureid) {
            if (StringUtil.isNotBlank(classstructureid)) {
                updateWrapper.eq(HydomcAsset::getClassstructureid, classstructureid);
            }
            return this;
        }

        public BuilderUpdateWrapper statusEq(String status) {
            if (StringUtil.isNotBlank(status)) {
                updateWrapper.eq(HydomcAsset::getStatus, status);
            }
            return this;
        }

        public BuilderUpdateWrapper sbxhhEq(String sbxhh) {
            if (StringUtil.isNotBlank(sbxhh)) {
                updateWrapper.eq(HydomcAsset::getSbxhh, sbxhh);
            }
            return this;
        }

        public BuilderUpdateWrapper cjsbxhEq(String cjsbxh) {
            if (StringUtil.isNotBlank(cjsbxh)) {
                updateWrapper.eq(HydomcAsset::getCjsbxh, cjsbxh);
            }
            return this;
        }

        public BuilderUpdateWrapper manufacturerEq(String manufacturer) {
            if (StringUtil.isNotBlank(manufacturer)) {
                updateWrapper.eq(HydomcAsset::getManufacturer, manufacturer);
            }
            return this;
        }

        public BuilderUpdateWrapper vendorEq(String vendor) {
            if (StringUtil.isNotBlank(vendor)) {
                updateWrapper.eq(HydomcAsset::getVendor, vendor);
            }
            return this;
        }

        public BuilderUpdateWrapper fwsEq(String fws) {
            if (StringUtil.isNotBlank(fws)) {
                updateWrapper.eq(HydomcAsset::getFws, fws);
            }
            return this;
        }

        public BuilderUpdateWrapper purchasepriceEq(Double purchaseprice) {
            if (null != purchaseprice) {
                updateWrapper.eq(HydomcAsset::getPurchaseprice, purchaseprice);
            }
            return this;
        }

        public BuilderUpdateWrapper zjsynxEq(Double zjsynx) {
            if (null != zjsynx) {
                updateWrapper.eq(HydomcAsset::getZjsynx, zjsynx);
            }
            return this;
        }

        public BuilderUpdateWrapper scrqEq(Date scrq) {
            if (null != scrq) {
                updateWrapper.eq(HydomcAsset::getScrq, scrq);
            }
            return this;
        }

        public BuilderUpdateWrapper cgrqEq(Date cgrq) {
            if (null != cgrq) {
                updateWrapper.eq(HydomcAsset::getCgrq, cgrq);
            }
            return this;
        }

        public BuilderUpdateWrapper azdateEq(Date azdate) {
            if (null != azdate) {
                updateWrapper.eq(HydomcAsset::getAzdate, azdate);
            }
            return this;
        }

        public BuilderUpdateWrapper installdateEq(Date installdate) {
            if (null != installdate) {
                updateWrapper.eq(HydomcAsset::getInstalldate, installdate);
            }
            return this;
        }

        public BuilderUpdateWrapper zbksrqEq(Date zbksrq) {
            if (null != zbksrq) {
                updateWrapper.eq(HydomcAsset::getZbksrq, zbksrq);
            }
            return this;
        }

        public BuilderUpdateWrapper zbjsrqEq(Date zbjsrq) {
            if (null != zbjsrq) {
                updateWrapper.eq(HydomcAsset::getZbjsrq, zbjsrq);
            }
            return this;
        }

        public BuilderUpdateWrapper zxzqEq(Integer zxzq) {
            if (null != zxzq) {
                updateWrapper.eq(HydomcAsset::getZxzq, zxzq);
            }
            return this;
        }

        public BuilderUpdateWrapper dxzqEq(Integer dxzq) {
            if (null != dxzq) {
                updateWrapper.eq(HydomcAsset::getDxzq, dxzq);
            }
            return this;
        }

        public BuilderUpdateWrapper wylxEq(String wylx) {
            if (StringUtil.isNotBlank(wylx)) {
                updateWrapper.eq(HydomcAsset::getWylx, wylx);
            }
            return this;
        }

        public BuilderUpdateWrapper sbglgsEq(String sbglgs) {
            if (StringUtil.isNotBlank(sbglgs)) {
                updateWrapper.eq(HydomcAsset::getSbglgs, sbglgs);
            }
            return this;
        }

        public BuilderUpdateWrapper hysbbmEq(String hysbbm) {
            if (StringUtil.isNotBlank(hysbbm)) {
                updateWrapper.eq(HydomcAsset::getHysbbm, hysbbm);
            }
            return this;
        }

        public BuilderUpdateWrapper sfhysyEq(String sfhysy) {
            if (StringUtil.isNotBlank(sfhysy)) {
                updateWrapper.eq(HydomcAsset::getSfhysy, sfhysy);
            }
            return this;
        }



        public BuilderUpdateWrapper ctxEq(String ctx) {
            if (StringUtil.isNotBlank(ctx)) {
                updateWrapper.eq(HydomcAsset::getCtx, ctx);
            }
            return this;
        }


        public BuilderUpdateWrapper sfzldEq(String sfzld) {
            if (StringUtil.isNotBlank(sfzld)) {
                updateWrapper.eq(HydomcAsset::getSfzld, sfzld);
            }
            return this;
        }

        public BuilderUpdateWrapper markEq(String mark) {
            if (StringUtil.isNotBlank(mark)) {
                updateWrapper.eq(HydomcAsset::getMark, mark);
            }
            return this;
        }

        public BuilderUpdateWrapper datastatusEq(String datastatus) {
            if (StringUtil.isNotBlank(datastatus)) {
                updateWrapper.eq(HydomcAsset::getDatastatus, datastatus);
            }
            return this;
        }

        public BuilderUpdateWrapper changedateEq(Date changedate) {
            if (null != changedate) {
                updateWrapper.eq(HydomcAsset::getChangedate, changedate);
            }
            return this;
        }

        public LambdaUpdateWrapper<HydomcAsset> builder() {
            return updateWrapper;
        }

    }

    public static class Builder {

        private HydomcAsset hydomcAsset = new HydomcAsset();

        public Builder siteid(String siteid) {
            hydomcAsset.setSiteid(siteid);
            return this;
        }

        public Builder sbybm(String sbybm) {
            hydomcAsset.setSbybm(sbybm);
            return this;
        }

        public Builder description(String description) {
            hydomcAsset.setDescription(description);
            return this;
        }

        public Builder wzqy(String wzqy) {
            hydomcAsset.setWzqy(wzqy);
            return this;
        }

        public Builder fwqy(String fwqy) {
            hydomcAsset.setFwqy(fwqy);
            return this;
        }

        public Builder sbxh(String sbxh) {
            hydomcAsset.setSbxh(sbxh);
            return this;
        }

        public Builder classstructureid(String classstructureid) {
            hydomcAsset.setClassstructureid(classstructureid);
            return this;
        }

        public Builder status(String status) {
            hydomcAsset.setStatus(status);
            return this;
        }

        public Builder sbxhh(String sbxhh) {
            hydomcAsset.setSbxhh(sbxhh);
            return this;
        }

        public Builder cjsbxh(String cjsbxh) {
            hydomcAsset.setCjsbxh(cjsbxh);
            return this;
        }

        public Builder manufacturer(String manufacturer) {
            hydomcAsset.setManufacturer(manufacturer);
            return this;
        }

        public Builder vendor(String vendor) {
            hydomcAsset.setVendor(vendor);
            return this;
        }

        public Builder fws(String fws) {
            hydomcAsset.setFws(fws);
            return this;
        }

        public Builder purchaseprice(Double purchaseprice) {
            hydomcAsset.setPurchaseprice(purchaseprice);
            return this;
        }

        public Builder zjsynx(Double zjsynx) {
            hydomcAsset.setZjsynx(zjsynx);
            return this;
        }

        public Builder scrq(Date scrq) {
            hydomcAsset.setScrq(scrq);
            return this;
        }

        public Builder cgrq(Date cgrq) {
            hydomcAsset.setCgrq(cgrq);
            return this;
        }

        public Builder azdate(Date azdate) {
            hydomcAsset.setAzdate(azdate);
            return this;
        }

        public Builder installdate(Date installdate) {
            hydomcAsset.setInstalldate(installdate);
            return this;
        }

        public Builder zbksrq(Date zbksrq) {
            hydomcAsset.setZbksrq(zbksrq);
            return this;
        }

        public Builder zbjsrq(Date zbjsrq) {
            hydomcAsset.setZbjsrq(zbjsrq);
            return this;
        }

        public Builder zxzq(Integer zxzq) {
            hydomcAsset.setZxzq(zxzq);
            return this;
        }

        public Builder dxzq(Integer dxzq) {
            hydomcAsset.setDxzq(dxzq);
            return this;
        }

        public Builder wylx(String wylx) {
            hydomcAsset.setWylx(wylx);
            return this;
        }

        public Builder sbglgs(String sbglgs) {
            hydomcAsset.setSbglgs(sbglgs);
            return this;
        }

        public Builder hysbbm(String hysbbm) {
            hydomcAsset.setHysbbm(hysbbm);
            return this;
        }

        public Builder sfhysy(String sfhysy) {
            hydomcAsset.setSfhysy(sfhysy);
            return this;
        }

        public Builder ctx(String ctx) {
            hydomcAsset.setCtx(ctx);
            return this;
        }

        public Builder sfzld(String sfzld) {
            hydomcAsset.setSfzld(sfzld);
            return this;
        }

        public Builder mark(String mark) {
            hydomcAsset.setMark(mark);
            return this;
        }

        public Builder datastatus(String datastatus) {
            hydomcAsset.setDatastatus(datastatus);
            return this;
        }

        public Builder changedate(Date changedate) {
            hydomcAsset.setChangedate(changedate);
            return this;
        }

        public HydomcAsset build() {
            return hydomcAsset;
        }

    }
}
