package com.persagy.transfer.pojo.dto;

import com.baomidou.mybatisplus.annotation.FieldStrategy;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.handlers.FastjsonTypeHandler;
import com.persagy.common.utils.StringUtil;
import com.persagy.db.model.BaseEntity;

import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

/**
 * 信息点定义表
 * 
 * @version 1.0.0
 * @company persagy
 * @author zhangqiankun
 * @date 2021-09-16 13:16:57
 */
@Getter
@Setter
@ToString
@EqualsAndHashCode(callSuper = false)
@TableName("rwd_def_funcid")
public class RwdDefFuncid extends BaseEntity<RwdDefFuncid> {
	private static final long serialVersionUID = -4533424950082519894L;

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String code; // 信息点编码,同类型下唯一,标准驼峰格式

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String origCode; // 信息点编码,同类型下唯一,旧版版格式,非驼峰,已弃用

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String name; // 信息点名称

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String aliasCode; // 编码别名

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String aliasName; // 别名

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String classCode; // 类型编码

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String type; // 平台级common,集团级group,项目级project

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String groupCode; // 集团编码

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String projectId; // 项目id

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String category; // 信息点分类:静态,脉冲,阶段,时序

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String firstTag; // 一级标签

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String secondTag; // 二级标签

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String priority; // 优先级

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String inputMode; // 输入方式

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String unit; // 单位

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String dataType; // 数据类型

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String origDataType; // 原数据类型,已弃用

	@TableField(updateStrategy = FieldStrategy.NOT_NULL)
	private Integer isMultiple; // 是否复数

	@TableField(updateStrategy = FieldStrategy.NOT_NULL)
	private Integer isRegion; // 是否区间

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String formater; // 数据格式

	@TableField(typeHandler = FastjsonTypeHandler.class)
	private Object dataSource; // 数据源取值范围/枚举值清单等,根据dataType有不同的内容

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String origDataSource; // 数据源取值范围/枚举值清单等,根据dataType有不同的内容,原始定义

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String note; // 备注

	@TableField(updateStrategy = FieldStrategy.NOT_NULL)
	private Integer subFlag; // 子分类标记:是否可以按此信息点进行子分类替换,同一类型下目前只支持一个子分类信息点

	@TableField(updateStrategy = FieldStrategy.NOT_NULL)
	private Integer weakPoint; // 虚点

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String shareType; // 通用信息点标记,1-通用信息点,2-个性化信息点

	@TableField(updateStrategy = FieldStrategy.NOT_NULL)
	private Integer orderSeq; // 逻辑排序序号

	public static Builder builder() {
		return new Builder();
	}

	public static class BuilderQueryWrapper {

		private LambdaQueryWrapper<RwdDefFuncid> queryWrapper = new LambdaQueryWrapper<RwdDefFuncid>();

		public BuilderQueryWrapper idEq(String id) {
			if (StringUtil.isNotBlank(id)) {
				queryWrapper.eq(RwdDefFuncid::getId, id);
			}
			return this;
		}

		public BuilderQueryWrapper codeEq(String code) {
			if (StringUtil.isNotBlank(code)) {
				queryWrapper.eq(RwdDefFuncid::getCode, code);
			}
			return this;
		}

		public BuilderQueryWrapper origCodeEq(String origCode) {
			if (StringUtil.isNotBlank(origCode)) {
				queryWrapper.eq(RwdDefFuncid::getOrigCode, origCode);
			}
			return this;
		}

		public BuilderQueryWrapper nameEq(String name) {
			if (StringUtil.isNotBlank(name)) {
				queryWrapper.eq(RwdDefFuncid::getName, name);
			}
			return this;
		}

		public BuilderQueryWrapper aliasCodeEq(String aliasCode) {
			if (StringUtil.isNotBlank(aliasCode)) {
				queryWrapper.eq(RwdDefFuncid::getAliasCode, aliasCode);
			}
			return this;
		}

		public BuilderQueryWrapper aliasNameEq(String aliasName) {
			if (StringUtil.isNotBlank(aliasName)) {
				queryWrapper.eq(RwdDefFuncid::getAliasName, aliasName);
			}
			return this;
		}

		public BuilderQueryWrapper classCodeEq(String classCode) {
			if (StringUtil.isNotBlank(classCode)) {
				queryWrapper.eq(RwdDefFuncid::getClassCode, classCode);
			}
			return this;
		}

		public BuilderQueryWrapper typeEq(String type) {
			if (StringUtil.isNotBlank(type)) {
				queryWrapper.eq(RwdDefFuncid::getType, type);
			}
			return this;
		}

		public BuilderQueryWrapper groupCodeEq(String groupCode) {
			if (StringUtil.isNotBlank(groupCode)) {
				queryWrapper.eq(RwdDefFuncid::getGroupCode, groupCode);
			}
			return this;
		}

		public BuilderQueryWrapper projectIdEq(String projectId) {
			if (StringUtil.isNotBlank(projectId)) {
				queryWrapper.eq(RwdDefFuncid::getProjectId, projectId);
			}
			return this;
		}

		public BuilderQueryWrapper categoryEq(String category) {
			if (StringUtil.isNotBlank(category)) {
				queryWrapper.eq(RwdDefFuncid::getCategory, category);
			}
			return this;
		}

		public BuilderQueryWrapper firstTagEq(String firstTag) {
			if (StringUtil.isNotBlank(firstTag)) {
				queryWrapper.eq(RwdDefFuncid::getFirstTag, firstTag);
			}
			return this;
		}

		public BuilderQueryWrapper secondTagEq(String secondTag) {
			if (StringUtil.isNotBlank(secondTag)) {
				queryWrapper.eq(RwdDefFuncid::getSecondTag, secondTag);
			}
			return this;
		}

		public BuilderQueryWrapper priorityEq(String priority) {
			if (StringUtil.isNotBlank(priority)) {
				queryWrapper.eq(RwdDefFuncid::getPriority, priority);
			}
			return this;
		}

		public BuilderQueryWrapper inputModeEq(String inputMode) {
			if (StringUtil.isNotBlank(inputMode)) {
				queryWrapper.eq(RwdDefFuncid::getInputMode, inputMode);
			}
			return this;
		}

		public BuilderQueryWrapper unitEq(String unit) {
			if (StringUtil.isNotBlank(unit)) {
				queryWrapper.eq(RwdDefFuncid::getUnit, unit);
			}
			return this;
		}

		public BuilderQueryWrapper dataTypeEq(String dataType) {
			if (StringUtil.isNotBlank(dataType)) {
				queryWrapper.eq(RwdDefFuncid::getDataType, dataType);
			}
			return this;
		}

		public BuilderQueryWrapper origDataTypeEq(String origDataType) {
			if (StringUtil.isNotBlank(origDataType)) {
				queryWrapper.eq(RwdDefFuncid::getOrigDataType, origDataType);
			}
			return this;
		}

		public BuilderQueryWrapper isMultipleEq(Integer isMultiple) {
			if (null != isMultiple) {
				queryWrapper.eq(RwdDefFuncid::getIsMultiple, isMultiple);
			}
			return this;
		}

		public BuilderQueryWrapper isRegionEq(Integer isRegion) {
			if (null != isRegion) {
				queryWrapper.eq(RwdDefFuncid::getIsRegion, isRegion);
			}
			return this;
		}

		public BuilderQueryWrapper formaterEq(String formater) {
			if (StringUtil.isNotBlank(formater)) {
				queryWrapper.eq(RwdDefFuncid::getFormater, formater);
			}
			return this;
		}

		public BuilderQueryWrapper dataSourceEq(Object dataSource) {
			if (null != dataSource) {
				queryWrapper.eq(RwdDefFuncid::getDataSource, dataSource);
			}
			return this;
		}

		public BuilderQueryWrapper origDataSourceEq(String origDataSource) {
			if (StringUtil.isNotBlank(origDataSource)) {
				queryWrapper.eq(RwdDefFuncid::getOrigDataSource, origDataSource);
			}
			return this;
		}

		public BuilderQueryWrapper noteEq(String note) {
			if (StringUtil.isNotBlank(note)) {
				queryWrapper.eq(RwdDefFuncid::getNote, note);
			}
			return this;
		}

		public BuilderQueryWrapper subFlagEq(Integer subFlag) {
			if (null != subFlag) {
				queryWrapper.eq(RwdDefFuncid::getSubFlag, subFlag);
			}
			return this;
		}

		public BuilderQueryWrapper weakPointEq(Integer weakPoint) {
			if (null != weakPoint) {
				queryWrapper.eq(RwdDefFuncid::getWeakPoint, weakPoint);
			}
			return this;
		}

		public BuilderQueryWrapper shareTypeEq(String shareType) {
			if (StringUtil.isNotBlank(shareType)) {
				queryWrapper.eq(RwdDefFuncid::getShareType, shareType);
			}
			return this;
		}

		public BuilderQueryWrapper orderSeqEq(Integer orderSeq) {
			if (null != orderSeq) {
				queryWrapper.eq(RwdDefFuncid::getOrderSeq, orderSeq);
			}
			return this;
		}

		public LambdaQueryWrapper<RwdDefFuncid> builder() {
			return queryWrapper;
		}

	}

	public static class BuilderUpdateWrapper {

		private LambdaUpdateWrapper<RwdDefFuncid> updateWrapper = new LambdaUpdateWrapper<RwdDefFuncid>();

		public BuilderUpdateWrapper idEq(String id) {
			if (StringUtil.isNotBlank(id)) {
				updateWrapper.eq(RwdDefFuncid::getId, id);
			}
			return this;
		}

		public BuilderUpdateWrapper codeEq(String code) {
			if (StringUtil.isNotBlank(code)) {
				updateWrapper.eq(RwdDefFuncid::getCode, code);
			}
			return this;
		}

		public BuilderUpdateWrapper origCodeEq(String origCode) {
			if (StringUtil.isNotBlank(origCode)) {
				updateWrapper.eq(RwdDefFuncid::getOrigCode, origCode);
			}
			return this;
		}

		public BuilderUpdateWrapper nameEq(String name) {
			if (StringUtil.isNotBlank(name)) {
				updateWrapper.eq(RwdDefFuncid::getName, name);
			}
			return this;
		}

		public BuilderUpdateWrapper aliasCodeEq(String aliasCode) {
			if (StringUtil.isNotBlank(aliasCode)) {
				updateWrapper.eq(RwdDefFuncid::getAliasCode, aliasCode);
			}
			return this;
		}

		public BuilderUpdateWrapper aliasNameEq(String aliasName) {
			if (StringUtil.isNotBlank(aliasName)) {
				updateWrapper.eq(RwdDefFuncid::getAliasName, aliasName);
			}
			return this;
		}

		public BuilderUpdateWrapper classCodeEq(String classCode) {
			if (StringUtil.isNotBlank(classCode)) {
				updateWrapper.eq(RwdDefFuncid::getClassCode, classCode);
			}
			return this;
		}

		public BuilderUpdateWrapper typeEq(String type) {
			if (StringUtil.isNotBlank(type)) {
				updateWrapper.eq(RwdDefFuncid::getType, type);
			}
			return this;
		}

		public BuilderUpdateWrapper groupCodeEq(String groupCode) {
			if (StringUtil.isNotBlank(groupCode)) {
				updateWrapper.eq(RwdDefFuncid::getGroupCode, groupCode);
			}
			return this;
		}

		public BuilderUpdateWrapper projectIdEq(String projectId) {
			if (StringUtil.isNotBlank(projectId)) {
				updateWrapper.eq(RwdDefFuncid::getProjectId, projectId);
			}
			return this;
		}

		public BuilderUpdateWrapper categoryEq(String category) {
			if (StringUtil.isNotBlank(category)) {
				updateWrapper.eq(RwdDefFuncid::getCategory, category);
			}
			return this;
		}

		public BuilderUpdateWrapper firstTagEq(String firstTag) {
			if (StringUtil.isNotBlank(firstTag)) {
				updateWrapper.eq(RwdDefFuncid::getFirstTag, firstTag);
			}
			return this;
		}

		public BuilderUpdateWrapper secondTagEq(String secondTag) {
			if (StringUtil.isNotBlank(secondTag)) {
				updateWrapper.eq(RwdDefFuncid::getSecondTag, secondTag);
			}
			return this;
		}

		public BuilderUpdateWrapper priorityEq(String priority) {
			if (StringUtil.isNotBlank(priority)) {
				updateWrapper.eq(RwdDefFuncid::getPriority, priority);
			}
			return this;
		}

		public BuilderUpdateWrapper inputModeEq(String inputMode) {
			if (StringUtil.isNotBlank(inputMode)) {
				updateWrapper.eq(RwdDefFuncid::getInputMode, inputMode);
			}
			return this;
		}

		public BuilderUpdateWrapper unitEq(String unit) {
			if (StringUtil.isNotBlank(unit)) {
				updateWrapper.eq(RwdDefFuncid::getUnit, unit);
			}
			return this;
		}

		public BuilderUpdateWrapper dataTypeEq(String dataType) {
			if (StringUtil.isNotBlank(dataType)) {
				updateWrapper.eq(RwdDefFuncid::getDataType, dataType);
			}
			return this;
		}

		public BuilderUpdateWrapper origDataTypeEq(String origDataType) {
			if (StringUtil.isNotBlank(origDataType)) {
				updateWrapper.eq(RwdDefFuncid::getOrigDataType, origDataType);
			}
			return this;
		}

		public BuilderUpdateWrapper isMultipleEq(Integer isMultiple) {
			if (null != isMultiple) {
				updateWrapper.eq(RwdDefFuncid::getIsMultiple, isMultiple);
			}
			return this;
		}

		public BuilderUpdateWrapper isRegionEq(Integer isRegion) {
			if (null != isRegion) {
				updateWrapper.eq(RwdDefFuncid::getIsRegion, isRegion);
			}
			return this;
		}

		public BuilderUpdateWrapper formaterEq(String formater) {
			if (StringUtil.isNotBlank(formater)) {
				updateWrapper.eq(RwdDefFuncid::getFormater, formater);
			}
			return this;
		}

		public BuilderUpdateWrapper dataSourceEq(Object dataSource) {
			if (null != dataSource) {
				updateWrapper.eq(RwdDefFuncid::getDataSource, dataSource);
			}
			return this;
		}

		public BuilderUpdateWrapper origDataSourceEq(String origDataSource) {
			if (StringUtil.isNotBlank(origDataSource)) {
				updateWrapper.eq(RwdDefFuncid::getOrigDataSource, origDataSource);
			}
			return this;
		}

		public BuilderUpdateWrapper noteEq(String note) {
			if (StringUtil.isNotBlank(note)) {
				updateWrapper.eq(RwdDefFuncid::getNote, note);
			}
			return this;
		}

		public BuilderUpdateWrapper subFlagEq(Integer subFlag) {
			if (null != subFlag) {
				updateWrapper.eq(RwdDefFuncid::getSubFlag, subFlag);
			}
			return this;
		}

		public BuilderUpdateWrapper weakPointEq(Integer weakPoint) {
			if (null != weakPoint) {
				updateWrapper.eq(RwdDefFuncid::getWeakPoint, weakPoint);
			}
			return this;
		}

		public BuilderUpdateWrapper shareTypeEq(String shareType) {
			if (StringUtil.isNotBlank(shareType)) {
				updateWrapper.eq(RwdDefFuncid::getShareType, shareType);
			}
			return this;
		}

		public BuilderUpdateWrapper orderSeqEq(Integer orderSeq) {
			if (null != orderSeq) {
				updateWrapper.eq(RwdDefFuncid::getOrderSeq, orderSeq);
			}
			return this;
		}

		public LambdaUpdateWrapper<RwdDefFuncid> builder() {
			return updateWrapper;
		}

	}

	public static class Builder {

		private RwdDefFuncid rwdDefFuncid = new RwdDefFuncid();

		public Builder id(String id) {
			rwdDefFuncid.setId(id);
			return this;
		}

		public Builder code(String code) {
			rwdDefFuncid.setCode(code);
			return this;
		}

		public Builder origCode(String origCode) {
			rwdDefFuncid.setOrigCode(origCode);
			return this;
		}

		public Builder name(String name) {
			rwdDefFuncid.setName(name);
			return this;
		}

		public Builder aliasCode(String aliasCode) {
			rwdDefFuncid.setAliasCode(aliasCode);
			return this;
		}

		public Builder aliasName(String aliasName) {
			rwdDefFuncid.setAliasName(aliasName);
			return this;
		}

		public Builder classCode(String classCode) {
			rwdDefFuncid.setClassCode(classCode);
			return this;
		}

		public Builder type(String type) {
			rwdDefFuncid.setType(type);
			return this;
		}

		public Builder groupCode(String groupCode) {
			rwdDefFuncid.setGroupCode(groupCode);
			return this;
		}

		public Builder projectId(String projectId) {
			rwdDefFuncid.setProjectId(projectId);
			return this;
		}

		public Builder category(String category) {
			rwdDefFuncid.setCategory(category);
			return this;
		}

		public Builder firstTag(String firstTag) {
			rwdDefFuncid.setFirstTag(firstTag);
			return this;
		}

		public Builder secondTag(String secondTag) {
			rwdDefFuncid.setSecondTag(secondTag);
			return this;
		}

		public Builder priority(String priority) {
			rwdDefFuncid.setPriority(priority);
			return this;
		}

		public Builder inputMode(String inputMode) {
			rwdDefFuncid.setInputMode(inputMode);
			return this;
		}

		public Builder unit(String unit) {
			rwdDefFuncid.setUnit(unit);
			return this;
		}

		public Builder dataType(String dataType) {
			rwdDefFuncid.setDataType(dataType);
			return this;
		}

		public Builder origDataType(String origDataType) {
			rwdDefFuncid.setOrigDataType(origDataType);
			return this;
		}

		public Builder isMultiple(Integer isMultiple) {
			rwdDefFuncid.setIsMultiple(isMultiple);
			return this;
		}

		public Builder isRegion(Integer isRegion) {
			rwdDefFuncid.setIsRegion(isRegion);
			return this;
		}

		public Builder formater(String formater) {
			rwdDefFuncid.setFormater(formater);
			return this;
		}

		public Builder dataSource(Object dataSource) {
			rwdDefFuncid.setDataSource(dataSource);
			return this;
		}

		public Builder origDataSource(String origDataSource) {
			rwdDefFuncid.setOrigDataSource(origDataSource);
			return this;
		}

		public Builder note(String note) {
			rwdDefFuncid.setNote(note);
			return this;
		}

		public Builder subFlag(Integer subFlag) {
			rwdDefFuncid.setSubFlag(subFlag);
			return this;
		}

		public Builder weakPoint(Integer weakPoint) {
			rwdDefFuncid.setWeakPoint(weakPoint);
			return this;
		}

		public Builder shareType(String shareType) {
			rwdDefFuncid.setShareType(shareType);
			return this;
		}

		public Builder orderSeq(Integer orderSeq) {
			rwdDefFuncid.setOrderSeq(orderSeq);
			return this;
		}

		public RwdDefFuncid build() {
			return rwdDefFuncid;
		}

	}
}
