package com.persagy.transfer.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.dynamic.datasource.annotation.DS;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.persagy.common.utils.StringUtil;
import com.persagy.transfer.constant.SwitchConstant;
import com.persagy.transfer.mapper.RwdObjectWdMapper;
import com.persagy.transfer.mapper.WdclassRelPersagyMapper;
import com.persagy.transfer.mapper.WdfacilityRelPersagyMapper;
import com.persagy.transfer.mapper.WdprojRelPersagyprojMapper;
import com.persagy.transfer.pojo.dto.*;
import com.persagy.transfer.service.IPersagyDbService;
import com.persagy.transfer.service.IWdDbService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * @description: 博锐尚格数据源业务处理
 * @author: YangWanYi
 * @create: 2021-09-16 20:29
 **/
@Service
@DS(value = SwitchConstant.DS_MASTER_1)
@Slf4j
public class PersagyDbServiceImpl implements IPersagyDbService {

    @Autowired
    private IWdDbService wdDbService;

    @Autowired
    private WdclassRelPersagyMapper wdclassRelPersagyMapper;

    @Autowired
    private WdprojRelPersagyprojMapper wdprojRelPersagyprojMapper;

    @Autowired
    private RwdObjectWdMapper rwdObjectWdMapper;

    @Autowired
    private WdfacilityRelPersagyMapper wdfacilityRelPersagyMapper;

    /**
     * @author YangWanYi
     * @describe 向万达数据库同步设备数据
     * @date 2021/9/16 11:38
     */
    @Override
    public void syncData2WD() {
        /*
            处理逻辑
            1、获取表wdclass_rel_persagy去重class_code的数据
            2、获取表wdproj_rel_persagyproj去重博锐尚格项目ID的数据
            3、根据1的class_code,2的persagy_project_id、obj_type='equipment'，获取表rwd_object_wd_*的数据
            4、对应数据进行insert或者update或者delete
         */

        // 1.获取表wdclass_rel_persagy去重class_code的数据
        log.debug("准备同步设备数据到万达数据库");
        LambdaQueryWrapper<WdclassRelPersagy> queryWdclassRelWrapper = new WdclassRelPersagy.BuilderQueryWrapper().builder();
        List<WdclassRelPersagy> funcList = this.wdclassRelPersagyMapper.selectList(queryWdclassRelWrapper);

        // 2.获取表wdproj_rel_persagyproj所有数据
        LambdaQueryWrapper<WdprojRelPersagyproj> queryProjRelWrapper = new WdprojRelPersagyproj.BuilderQueryWrapper().builder();
        List<WdprojRelPersagyproj> projList = this.wdprojRelPersagyprojMapper.selectList(queryProjRelWrapper);

        // 3.遍历获取rwd_object_wd_?的数据
        List<RwdObjectWd> rwdObjecWdList;
        final String OBJ_TYPE = "equipment"; // 对象分类（设备类）
        List<String> classCodeList = new ArrayList<>();
        List<String> persagyProjectIdList = new ArrayList<>();
        for (WdclassRelPersagy wdclassRelPersagy : funcList) {
            for (WdprojRelPersagyproj wdprojRelPersagyproj : projList) {
                // classCode和persagyProjectid去重
                if (classCodeList.contains(wdclassRelPersagy.getClassCode()) || persagyProjectIdList.contains(wdprojRelPersagyproj.getPersagyProjectid())) {
                    log.debug("有已经处理过的BDTP类编码或者博锐尚格项目id，准备跳过此次处理");
                    continue;
                }
                classCodeList.add(wdclassRelPersagy.getClassCode());
                persagyProjectIdList.add(wdprojRelPersagyproj.getPersagyProjectid());
                // 根据外循环对象的classCode、objType='equipment'，内循环对象的persagyProjectId,查询wd_object_wd_?表
                rwdObjecWdList = this.rwdObjectWdMapper.listByProjectId(StringUtil.lowerFirst(wdprojRelPersagyproj.getPersagyProjectid()), wdclassRelPersagy.getClassCode(), OBJ_TYPE);
                if (rwdObjecWdList != null && !rwdObjecWdList.isEmpty()) {
                    this.handleFieldMapping(rwdObjecWdList, wdprojRelPersagyproj, wdclassRelPersagy);
                }
            }
        }
    }

    /**
     * @param rwdObjecWdList       博锐尚格的项目对象
     * @param wdprojRelPersagyproj 万达项目ID与博锐尚格项目ID映射表实体
     * @author YangWanYi
     * @describe 同步万达设备数据的新增与更新
     * @date 2021/9/16 14:19
     */
    private void handleFieldMapping(List<RwdObjectWd> rwdObjecWdList, WdprojRelPersagyproj wdprojRelPersagyproj, WdclassRelPersagy wdclassRelPersagy) {
        JSONObject infosObj;
        HydomcAsset hydomcAsset = null; // 万达数据库的设备信息表实体
        List<WdfacilityRelPersagy> wdfacilityRelList = null;
        for (RwdObjectWd rwdObjectWd : rwdObjecWdList) {
            infosObj = JSONObject.parseObject(rwdObjectWd.getInfos());
            if (infosObj != null && !infosObj.isEmpty()) {
                /*万达设备信息对象数据同步*/
                this.wdDbService.sycnHydomcAsset(infosObj, wdprojRelPersagyproj.getWdProjectid(), hydomcAsset, rwdObjectWd.getValid(), rwdObjectWd.getUpdateTime(), wdclassRelPersagy.getClassstructureid(), rwdObjectWd.getUpdateUser());
                /*万达设备参数信息数据同步*/
                if (wdfacilityRelList == null) { // 循环万达项目ID与博锐尚格项目ID映射表数据时，wdfacility_rel_persagy只查询一次
                    wdfacilityRelList = this.listWdfacilityRelPersagy(wdclassRelPersagy.getWdClassCode(), wdclassRelPersagy.getClassstructureid());
                }
                this.wdDbService.sycnHydomcAssetspec(wdfacilityRelList, wdprojRelPersagyproj.getWdProjectid(), infosObj, rwdObjectWd.getUpdateTime());
            }
        }
    }


    /**
     * @param wdClassCode      万达设备类编码 （从wdclass_rel_persagy获取）
     * @param classStructureId 万达设备分类表id （从wdclass_rel_persagy获取）
     * @return java.util.List<com.persagy.transfer.pojo.dto.WdfacilityRelPersagy>
     * @author YangWanYi
     * @describe 根据万达设备类编码和万达设备分类表id查询表wdfacility_rel_persagy数据
     * @date 2021/9/16 17:49
     */
    private List<WdfacilityRelPersagy> listWdfacilityRelPersagy(String wdClassCode, String classStructureId) {
        HashMap<String, Object> columnMap = new HashMap<>();
        columnMap.put("wd_class_code", wdClassCode); // 万达设备类编码
        columnMap.put("classstructureid", classStructureId); // 万达设备分类表id
        return this.wdfacilityRelPersagyMapper.selectByMap(columnMap);
    }
}
