package com.persagy.transfer.utils;

import java.util.Date;

import org.apache.commons.lang3.StringUtils;

import com.persagy.common.utils.DateUtil;
import com.persagy.common.utils.StringUtil;

import cn.hutool.core.date.DateTime;

/**
 * @description: 字符串相关扩展工具类
 * @author: YangWanYi
 * @create: 2021-09-16 21:05
 **/
public class StringTool {

	/**
	 * 将object类型转为string类型
	 * 
	 * @param obj
	 * @return
	 * @date 2021年9月27日 下午6:07:20
	 */
    public static String object2String(Object obj) {
    	if (obj == null) {
    		return StringUtils.EMPTY;
		}
    	String valueOf = String.valueOf(obj);
    	if (StringUtil.isBlank(valueOf) || "null".equalsIgnoreCase(valueOf.trim())) {
    		return StringUtils.EMPTY;
		}
    	
    	return valueOf.trim();
    }

    /**
	 * 将object类型转为Double类型
	 * 
	 * @param obj
	 * @return
	 * @date 2021年9月27日 下午6:07:20
	 */
    public static Double object2Double(Object obj) {
    	if (obj == null) {
    		return null;
		}
    	String valueOf = String.valueOf(obj);
    	if (StringUtil.isBlank(valueOf) || "null".equalsIgnoreCase(valueOf.trim())) {
    		return null;
		}
    	
    	return Double.valueOf(valueOf.trim());
    }

    /**
     * 将object类型转为Date类型
     * 
     * @param obj
     * @return
     * @date 2021年9月27日 下午6:10:42
     */
    public static Date object2DateTime(Object obj) {
    	if (obj == null) {
    		return null;
		}
    	if (obj instanceof Long) {
			return new Date((long)obj);
		}
    	
    	try {
        	String valueOf = String.valueOf(obj);
        	DateTime dateTime = DateUtil.parse(valueOf);
        	return dateTime == null ? null : dateTime.toJdkDate();
		} catch (Exception e) {
			e.printStackTrace();
		}
    	
    	return null;
    }
    
    /**
     * 将object类型转为 sql Date类型
     * 
     * @param obj
     * @return
     * @date 2021年9月27日 下午6:10:42
     */
    public static Date object2SqlDate(Object obj) {
    	if (obj == null) {
    		return null;
		}
    	if (obj instanceof Long) {
			return new java.sql.Date((long)obj);
		}
    	
    	try {
        	String valueOf = String.valueOf(obj);
        	DateTime dateTime = DateUtil.parse(valueOf);
        	return dateTime == null ? null : new java.sql.Date(dateTime.getTime());
		} catch (Exception e) {
			e.printStackTrace();
		}
    	
    	return null;
    }

    /**
	 * 将object类型转为Integer类型
	 * 
	 * @param obj
	 * @return
	 * @date 2021年9月27日 下午6:07:20
	 */
    public static Integer object2Integer(Object obj) {
    	if (obj == null) {
    		return null;
		}
    	String valueOf = String.valueOf(obj);
    	if (StringUtil.isBlank(valueOf) || "null".equalsIgnoreCase(valueOf.trim())) {
    		return null;
		}
    	
    	return Integer.valueOf(valueOf.trim());
    }

}
